@@ -7,24 +7,23 @@
  * 	Miguel de Icaza
  * 	Nat Friedman
  * 	Gabriel Burt
+ * 	Markus Lindqvist <markus.lindqvist@iki.fi>
  *
  * This is free software. See COPYING for details.
  */
 
 using GLib;
 using Gdk;
-using Gnome;
 using Gtk;
-using GtkSharp;
 using System.Collections;
 using System.IO;
 using System;
 using Mono.Unix;
 
-using FSpot.Widgets;
 using FSpot;
 using FSpot.Utils;
 using FSpot.UI.Dialog;
+using FSpot.Widgets;
 
 public class ImportCommand : GladeDialog
 {
@@ -188,7 +187,6 @@ public class ImportCommand : GladeDialog
 	}
 
 	internal abstract class ImportSource {
-		public object Backend;
 		public Gdk.Pixbuf Icon;
 		public string Name;
 	}
@@ -259,7 +257,7 @@ public class ImportCommand : GladeDialog
 				}
 			} else {
 				ImportSource source = new BrowseSource (Catalog.GetString ("(No Cameras Detected)"),
-									"emblem-camera");
+									"camera-photo");
 				item = new SourceItem (source);
 				item.Activated += HandleActivated;
 				item.Sensitive = false;
@@ -344,7 +342,7 @@ public class ImportCommand : GladeDialog
 	PhotoStore store;
 	FSpot.Delay step;
 	
-	FSpot.PhotoImageView photo_view;
+	PhotoImageView photo_view;
 	ImportBackend importer;
 	FSpot.Widgets.IconView tray;
 
@@ -526,6 +524,13 @@ public class ImportCommand : GladeDialog
 		importer = null;
 	}
 	
+	void SavePreferences ()
+	{
+		Preferences.Set(Preferences.IMPORT_COPY_FILES, copy_check.Active);
+		Preferences.Set(Preferences.IMPORT_INCLUDE_SUBFOLDERS, recurse_check.Active);
+		Preferences.Set(Preferences.IMPORT_CHECK_DUPLICATES, duplicate_check.Active);
+	}
+	
 	public void HandleImportBrowse (object o, EventArgs args) 
 	{
 		string path = ChoosePath ();
@@ -538,24 +543,26 @@ public class ImportCommand : GladeDialog
 	{
 		string path = null;
 
-		CompatFileChooserDialog file_selector =
-			new CompatFileChooserDialog ("Import", this.Dialog,
-						     CompatFileChooserDialog.Action.SelectFolder);
+		FileChooserDialog file_chooser =
+			new FileChooserDialog (Catalog.GetString ("Import"), this.Dialog,
+					FileChooserAction.SelectFolder,
+					Stock.Cancel, ResponseType.Cancel,
+					Stock.Open, ResponseType.Ok);
 
-		file_selector.SelectMultiple = false;
+		file_chooser.SelectMultiple = false;
 
 		if (ImportPath != null)
-			file_selector.Filename = ImportPath;
+			file_chooser.SetFilename (ImportPath);
 		else
-			file_selector.Filename = FSpot.Global.HomeDirectory;
+			file_chooser.SetFilename (FSpot.Global.HomeDirectory);
 
-		int response = file_selector.Run ();
+		int response = file_chooser.Run ();
 
 		if ((ResponseType) response == ResponseType.Ok) {
-			path = file_selector.Filename;
+			path = file_chooser.Filename;
 		}
 
-		file_selector.Destroy ();
+		file_chooser.Destroy ();
 		return path;
 	}
 
@@ -578,25 +585,32 @@ public class ImportCommand : GladeDialog
 	       
 		idle_start.Start ();
 	}
+	
+	private void LoadPreferences ()
+	{
+		if (FSpot.Preferences.Get<int> (FSpot.Preferences.IMPORT_WINDOW_WIDTH) > 0)
+			this.Dialog.Resize (FSpot.Preferences.Get<int> (FSpot.Preferences.IMPORT_WINDOW_WIDTH), FSpot.Preferences.Get<int> (FSpot.Preferences.IMPORT_WINDOW_HEIGHT));
+
+		if (FSpot.Preferences.Get<int> (FSpot.Preferences.IMPORT_WINDOW_PANE_POSITION) > 0)
+			import_hpaned.Position = FSpot.Preferences.Get<int> (FSpot.Preferences.IMPORT_WINDOW_PANE_POSITION);
+
+		copy_check.Active = Preferences.Get<bool> (Preferences.IMPORT_COPY_FILES);
+		recurse_check.Active = Preferences.Get<bool> (Preferences.IMPORT_INCLUDE_SUBFOLDERS);
+		duplicate_check.Active = Preferences.Get<bool> (Preferences.IMPORT_CHECK_DUPLICATES);
+	}
 
 	public int ImportFromFile (PhotoStore store, string path)
 	{
 		this.store = store;
 		this.CreateDialog ("import_dialog");
-		
 		this.Dialog.TransientFor = main_window;
 		this.Dialog.WindowPosition = Gtk.WindowPosition.CenterOnParent;
 		this.Dialog.Response += HandleDialogResponse;
-
- 		if (FSpot.Preferences.Get<int> (FSpot.Preferences.IMPORT_WINDOW_WIDTH) > 0)
- 			this.Dialog.Resize (FSpot.Preferences.Get<int> (FSpot.Preferences.IMPORT_WINDOW_WIDTH), FSpot.Preferences.Get<int> (FSpot.Preferences.IMPORT_WINDOW_HEIGHT));
-
- 		if (FSpot.Preferences.Get<int> (FSpot.Preferences.IMPORT_WINDOW_PANE_POSITION) > 0)
-			import_hpaned.Position = FSpot.Preferences.Get<int> (FSpot.Preferences.IMPORT_WINDOW_PANE_POSITION);
-
-	        AllowFinish = false;
-		
 		this.Dialog.DefaultResponse = ResponseType.Ok;
+
+		AllowFinish = false;
+		
+		LoadPreferences ();
 		
 		//import_folder_entry.Activated += HandleEntryActivate;
 		duplicate_check.Toggled += HandleRecurseToggled;
@@ -615,7 +629,7 @@ public class ImportCommand : GladeDialog
 		tray.DisplayTags = false;
 		tray.Show ();
 
-		photo_view = new FSpot.PhotoImageView (collection);
+		photo_view = new PhotoImageView (collection);
 		photo_scrolled.Add (photo_view);
 		photo_scrolled.SetSizeRequest (200, 200);
 		photo_view.Show ();
@@ -624,8 +638,8 @@ public class ImportCommand : GladeDialog
 		GtkUtil.ModifyColors (photo_scrolled);
 		GtkUtil.ModifyColors (photo_view);
 
-		photo_view.Pixbuf = GtkUtil.TryLoadIcon (FSpot.Global.IconTheme, "f-spot", 48, (Gtk.IconLookupFlags)0);
-		photo_view.Fit = true;
+		photo_view.Pixbuf = GtkUtil.TryLoadIcon (FSpot.Global.IconTheme, "f-spot", 128, (Gtk.IconLookupFlags)0);
+		photo_view.ZoomFit (false);
 			
 		tag_entry = new FSpot.Widgets.TagEntry (MainWindow.Toplevel.Database.Tags, false);
 		tag_entry.UpdateFromTagNames (new string []{});
@@ -679,6 +693,7 @@ public class ImportCommand : GladeDialog
 
 		if (response == ResponseType.Ok) {
 			this.UpdateTagStore (tag_entry.GetTypedTagNames ());
+			SavePreferences ();
 			this.Finish ();
 
 			if (tags_selected != null && tags_selected.Count > 0) {
@@ -723,10 +738,10 @@ public class ImportCommand : GladeDialog
 				// Note for translators: 'Import Tags' is no command, it means 'Tags used in Import'
 				Category default_category = db.Tags.GetTagByName (Catalog.GetString ("Import Tags")) as Category;
 				if (default_category == null) {
-					default_category = db.Tags.CreateCategory (null, Catalog.GetString ("Import Tags"));
-					default_category.ThemeIconName = "f-spot-imported-xmp-tags.png"; 
+					default_category = db.Tags.CreateCategory (null, Catalog.GetString ("Import Tags"), false);
+					default_category.ThemeIconName = "gtk-new"; 
 				}
-				t = db.Tags.CreateCategory (default_category, tagname) as Tag;
+				t = db.Tags.CreateCategory (default_category, tagname, false) as Tag;
 				db.Tags.Commit (t);
 			}
 
